@@ -12,15 +12,22 @@ from rich.syntax import Syntax
 
 from .cached_object import CachedObject
 from .explorer_layout import ExplorerLayout, ExplorerState
-from .help_layout import HelpLayout, HelpState
+from .help_layout import HelpLayout, HelpState, random_error_quote
 from .overview_layout import OverviewLayout, OverviewState, PreviewState
 from .stack_layout import StackFrame, StackLayout
 
-version = "1.0"
+version = "1.1"
 
+# TODO fix explore(namedtuple)
 # TODO methods filter
 # or just a type filter?
 # TODO empty overview layouts for when there are 0 public attributes
+# TODO search filter
+# TODO generate the explorer lines on cachedobject instatiation to speed up processing
+#    - Auto generate ALL renderables on init. docstring, repr (i think already done) type, len, source, etc
+# TODO use inspect.ismethod inspect.ismodule, inspect.isfunction isclass
+
+console = Console()
 
 
 class Explorer:
@@ -34,11 +41,10 @@ class Explorer:
         # self.head_obj = cached_obj
         self.cached_obj: CachedObject = cached_obj
         self.term = Terminal()
-        self.console = Console()
         self.stack = StackLayout(head_obj=self.cached_obj, visible=False)
         self.help_layout = HelpLayout(version, visible=False, ratio=3)
         self.explorer_layout = ExplorerLayout(cached_obj=cached_obj)
-        self.overview_layout = OverviewLayout()
+        self.overview_layout = OverviewLayout(ratio=3)
 
         self.stack.append(
             StackFrame(
@@ -62,13 +68,25 @@ class Explorer:
 
         with self.term.cbreak(), self.term.hidden_cursor():
             while key not in ("q", "Q"):
-                self.draw()
-                key = self.term.inkey()
-                res = self.process_key_event(key)
+                try:
+                    self.draw()
+                    key = self.term.inkey()
+                    res = self.process_key_event(key)
 
-                # If the object is returned as a response then close the explorer and return the selected object
-                if res:
-                    break
+                    # If the object is returned as a response then close the explorer and return the selected object
+                    if res:
+                        break
+
+                except RuntimeError as err:
+                    # Some kind of error during resizing events. Ignore and continue
+                    if (
+                        err.args[0]
+                        == "reentrant call inside <_io.BufferedWriter name='<stdout>'>"
+                    ):
+                        pass
+                    # Otherwise it is a new error. Raise
+                    else:
+                        raise err
         return res
 
     def process_key_event(self, key: blessed.keyboard.Keystroke) -> Any:
@@ -88,8 +106,8 @@ class Explorer:
 
             # Fullscreen
             elif key == "f":
-                with self.console.capture() as capture:
-                    self.console.print(self.help_layout.text)
+                with console.capture() as capture:
+                    console.print(self.help_layout.text)
                 str_out = capture.get()
                 pydoc.pager(str_out)
                 return
@@ -140,12 +158,15 @@ class Explorer:
 
         # Enter
         elif key in ("\n", "l") or key.code == self.term.KEY_RIGHT:
+
             if self.stack.visible:
                 new_cached_obj = self.stack.select()
             else:
                 new_cached_obj = self.cached_obj.selected_cached_obj
 
-            if new_cached_obj.obj is not None and not callable(new_cached_obj.obj):
+            if new_cached_obj.obj not in (None, [], {}, (), set()) and not callable(
+                new_cached_obj.obj
+            ):
                 self.explorer_layout = ExplorerLayout(cached_obj=new_cached_obj)
                 self.cached_obj = new_cached_obj
                 self.cached_obj.cache_attributes()
@@ -226,8 +247,8 @@ class Explorer:
                     fullscreen=True
                 )
 
-            with self.console.capture() as capture:
-                self.console.print(printable)
+            with console.capture() as capture:
+                console.print(printable)
 
             str_out = capture.get()
             pydoc.pager(str_out)
@@ -245,12 +266,16 @@ class Explorer:
         if self.stack.visible:
             layout = Layout()
             layout.split_column(
-                self.explorer_layout(self.cached_obj, term_width=self.term.width),
+                self.explorer_layout(
+                    term_width=self.term.width, term_height=self.term.height
+                ),
                 self.stack(term_width=self.term.width),
             )
             return layout
         else:
-            return self.explorer_layout(self.cached_obj, term_width=self.term.width)
+            return self.explorer_layout(
+                term_width=self.term.width, term_height=self.term.height
+            )
 
     def get_overview_layout(self) -> Layout:
         if self.help_layout.visible:
@@ -259,7 +284,7 @@ class Explorer:
             return self.overview_layout(
                 cached_obj=self.cached_obj.selected_cached_obj,
                 term_height=self.term.height,
-                console=self.console,
+                console=console,
             )
 
     def draw(self, *args):
@@ -269,7 +294,7 @@ class Explorer:
 
         layout.split_row(self.get_explorer_layout(), self.get_overview_layout())
 
-        title = self.cached_obj.repr
+        title = self.cached_obj.title
 
         object_explorer = Panel(
             layout,
@@ -287,6 +312,7 @@ class Explorer:
 
     @property
     def panel_height(self) -> int:
+        # TODO this shouldn't be here
         if self.stack.visible:
             return (self.term.height - 10) // 2
         else:
@@ -295,4 +321,18 @@ class Explorer:
 
 def explore(obj: Any) -> Any:
     """ Run the explorer on the given object """
-    return Explorer(obj).explore()
+    try:
+        e = Explorer(obj)
+        return e.explore()
+    except Exception as e:
+        console.print_exception(show_locals=True)
+        print()
+        rprint(f"[red]{random_error_quote()}")
+        formatted_link = f"https://github.com/kylepollina/objexplore/issues/new?assignees=&labels=&template=bug_report.md&title={e}".replace(
+            " ", "+"
+        )
+        print("Please report the issue here:")
+        rprint(f"   [link={formatted_link}][u]{formatted_link}[/u][/link]")
+        rprint(
+            "[yellow italic]Make sure to copy/paste the above traceback to the issue to make the issue quicker to solve!"
+        )
